@@ -275,7 +275,7 @@ class Client(PyQt5.QtCore.QObject):
     DEFAULT_PORT = 7624
 
     # timeout for client to server
-    CONNECTION_TIMEOUT = 1000
+    CONNECTION_TIMEOUT = 3000
 
     def __init__(self,
                  host=None,
@@ -416,10 +416,11 @@ class Client(PyQt5.QtCore.QObject):
         """
 
         self.connected = False
-        self.clearParser()
         self.signals.serverDisconnected.emit(self.devices)
+        self.clearParser()
         self.clearDevices(deviceName)
-        self.socket.abort()
+        self.socket.close()
+
         return True
 
     @PyQt5.QtCore.pyqtSlot()
@@ -430,6 +431,7 @@ class Client(PyQt5.QtCore.QObject):
         :return: nothing
         """
 
+        self.connected = False
         self.log.warning('INDI client disconnected')
 
     def isServerConnected(self):
