@@ -100,16 +100,22 @@ class Client(indibase.indiBase.Client):
     logger = logging.getLogger(__name__)
 
     # socket timeout for testing if server is present
-    SOCKET_TIMEOUT = 5
+    SOCKET_TIMEOUT = 1
     # cycle timer for checking server up
-    CYCLE_SERVER_UP = 5500
+    CYCLE_SERVER_UP = 5000
 
     def __init__(self,
                  host=None,
+                 threadPool=None
                  ):
         super().__init__(host=host)
 
-        self.threadpool = PyQt5.QtCore.QThreadPool()
+        if threadPool is None:
+            self.threadPool = PyQt5.QtCore.QThreadPool()
+        else:
+            self.threadPool = threadPool
+
+        self.threadPool.setExpiryTimeout(300000)
         self.mutexServerUp = PyQt5.QtCore.QMutex()
 
         self.timerServerUp = PyQt5.QtCore.QTimer()
@@ -129,12 +135,12 @@ class Client(indibase.indiBase.Client):
         try:
             client.connect(self.host)
         except Exception:
-            client.close()
             suc = False
         else:
+            suc = True
+        finally:
             client.shutdown(socket.SHUT_RDWR)
             client.close()
-            suc = True
 
         return suc
 
@@ -149,10 +155,6 @@ class Client(indibase.indiBase.Client):
             suc = self.connectServer()
             self.logger.info(f'Connect to server, result: {suc}')
             return suc
-        elif not result and self.connected:
-            suc = self.disconnectServer()
-            self.logger.info(f'Disconnect from server, result: {suc}')
-            return suc
         else:
             return False
 
@@ -191,7 +193,7 @@ class Client(indibase.indiBase.Client):
         worker.signals.finished.connect(self.clearCycleCheckServerUp)
         worker.signals.result.connect(self.checkServerUpResult)
         worker.signals.error.connect(self.errorCycleCheckServerUp)
-        self.threadpool.start(worker)
+        self.threadPool.start(worker)
 
     def startTimers(self):
         """
